GUACAMOLE-474: Do not allow RDPDR file downloads via "get" instructions if downloads are disabled.
diff --git a/src/protocols/rdp/download.c b/src/protocols/rdp/download.c
index fad2932..d70b8e1 100644
--- a/src/protocols/rdp/download.c
+++ b/src/protocols/rdp/download.c
@@ -148,8 +148,8 @@
 
     }
 
-    /* Otherwise, send file contents */
-    else {
+    /* Otherwise, send file contents if downloads are allowed */
+    else if (!fs->disable_download) {
 
         /* Create stream data */
         guac_rdp_download_status* download_status = malloc(sizeof(guac_rdp_download_status));
@@ -167,6 +167,10 @@
 
     }
 
+    else
+        guac_client_log(client, GUAC_LOG_INFO, "Unable to download file "
+                "\"%s\", file downloads have been disabled.", name);
+
     guac_socket_flush(user->socket);
     return 0;
 }